@@ -13,6 +13,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from neutron.callbacks import events
+from neutron.callbacks import registry
+from neutron.callbacks import resources
+from neutron import manager
+
 from networking_l2gw.db.l2gateway import db_query
 from networking_l2gw.db.l2gateway import l2gateway_models as models
 from networking_l2gw.extensions import l2gateway
@@ -22,11 +27,7 @@ from networking_l2gw.services.l2gateway.common import constants
 from networking_l2gw.services.l2gateway.common import l2gw_validators
 from networking_l2gw.services.l2gateway import exceptions as l2gw_exc
 
-from neutron_lib.callbacks import events
-from neutron_lib.callbacks import registry
-from neutron_lib.callbacks import resources
 from neutron_lib import exceptions
-from neutron_lib.plugins import directory
 from oslo_log import log as logging
 from oslo_utils import uuidutils
 from sqlalchemy.orm import exc as sa_orm_exc
@@ -129,7 +130,7 @@ class L2GatewayMixin(l2gateway.L2GatewayPluginBase,
     def _retrieve_gateway_connections(self, context, gateway_id,
                                       mapping_info={}, only_one=False):
         filters = {'l2_gateway_id': [gateway_id]}
-        for k, v in mapping_info.items():
+        for k, v in mapping_info.iteritems():
             if v and k != constants.SEG_ID:
                 filters[k] = [v]
         query = self._get_collection_query(context,
@@ -289,29 +290,24 @@ class L2GatewayMixin(l2gateway.L2GatewayPluginBase,
         with context.session.begin(subtransactions=True):
             gw_db = self._get_l2_gateway(context, l2_gw_id)
             tenant_id = self._get_tenant_id_for_create(context, gw_db)
+            if self._retrieve_gateway_connections(context,
+                                                  l2_gw_id,
+                                                  nw_map):
+                raise l2gw_exc.L2GatewayConnectionExists(mapping=nw_map,
+                                                         gateway_id=l2_gw_id)
             nw_map['tenant_id'] = tenant_id
+            connection_id = uuidutils.generate_uuid()
+            nw_map['id'] = connection_id
             if not segmentation_id:
                 nw_map['segmentation_id'] = "0"
-            conn_db = self._retrieve_gateway_connections(context, l2_gw_id,
-                                                         nw_map)
-            if not conn_db:
-                connection_id = uuidutils.generate_uuid()
-                nw_map['id'] = connection_id
-                gw_db.network_connections.append(
-                    models.L2GatewayConnection(**nw_map))
-                gw_db = models.L2GatewayConnection(
-                    id=connection_id,
-                    tenant_id=tenant_id,
-                    network_id=network_id,
-                    l2_gateway_id=l2_gw_id,
-                    segmentation_id=segmentation_id)
-                return self._make_l2gw_connections_dict(gw_db)
-            return self._make_l2gw_connections_dict(conn_db[0])
-
-    def get_l2_gateway_connections_count(self, context, filters=None):
-        return len(self._get_collection(context, models.L2GatewayConnection,
-                                        self._make_l2gw_connections_dict,
-                                        filters=filters))
+            gw_db.network_connections.append(
+                models.L2GatewayConnection(**nw_map))
+            gw_db = models.L2GatewayConnection(id=connection_id,
+                                               tenant_id=tenant_id,
+                                               network_id=network_id,
+                                               l2_gateway_id=l2_gw_id,
+                                               segmentation_id=segmentation_id)
+        return self._make_l2gw_connections_dict(gw_db)
 
     def get_l2_gateway_connections(self, context, filters=None,
                                    fields=None,
@@ -499,41 +495,21 @@ class L2GatewayMixin(l2gateway.L2GatewayPluginBase,
         gw = l2_gateway[self.gateway_resource]
         devices = None
         dev_db = None
+        l2gw_db = None
         if 'devices' in gw:
             devices = gw['devices']
-        if not devices:
-            return
         with context.session.begin(subtransactions=True):
-            # Attemp to retrieve l2gw
-            gw_db = self._get_l2_gateway(context, id)
+            l2gw_db = self._get_l2_gateway(context, id)
+            if l2gw_db.network_connections:
+                raise l2gw_exc.L2GatewayInUse(gateway_id=id)
             if devices:
                 for device in devices:
                     dev_name = device['device_name']
-                    dev_db = self._get_l2gw_devices_by_name_andl2gwid(
-                        context, dev_name, id)
+                    dev_db = (self._get_l2gw_devices_by_name_andl2gwid(
+                        context, dev_name, id))
                     if not dev_db:
-                        raise l2gw_exc.L2GatewayDeviceNotFound(
-                            device_id=dev_name)
+                        raise l2gw_exc.L2GatewayDeviceNotFound(device_id="")
                     self.validate_device_name(context, dev_name, id)
-                    interface_list = device['interfaces']
-                    if not interface_list:
-                        raise l2gw_exc.L2GatewayInterfaceRequired()
-                    if constants.SEG_ID in interface_list[0]:
-                        for interfaces in interface_list:
-                            if constants.SEG_ID not in interfaces:
-                                raise l2gw_exc.L2GatewaySegmentationRequired()
-                    if constants.SEG_ID not in interface_list[0]:
-                        for interfaces in interface_list[1:]:
-                            if constants.SEG_ID in interfaces:
-                                raise l2gw_exc.L2GatewaySegmentationRequired()
-                    if gw_db.devices:
-                        if gw_db.devices[0].interfaces[0]['segmentation_id']:
-                            if constants.SEG_ID not in interface_list[0]:
-                                raise l2gw_exc.L2GatewaySegmentationIDExists()
-                        else:
-                            if constants.SEG_ID in interface_list[0]:
-                                raise l2gw_exc.\
-                                    L2GatewaySegmentationIDNotExists()
 
     def validate_l2_gateway_connection_for_create(self, context,
                                                   l2_gateway_connection):
@@ -541,8 +517,6 @@ class L2GatewayMixin(l2gateway.L2GatewayPluginBase,
         gw_connection = l2_gateway_connection[self.connection_resource]
         l2_gw_id = gw_connection.get('l2_gateway_id')
         network_id = gw_connection.get('network_id')
-        plugin = directory.get_plugin()
-        plugin.get_network(context, network_id)
         nw_map = {}
         nw_map['network_id'] = network_id
         nw_map['l2_gateway_id'] = l2_gw_id
@@ -572,7 +546,8 @@ class L2GatewayMixin(l2gateway.L2GatewayPluginBase,
 
 
 def l2gw_callback(resource, event, trigger, **kwargs):
-    l2gwservice = directory.get_plugin(constants.L2GW)
+    l2gwservice = manager.NeutronManager.get_service_plugins().get(
+        constants.L2GW)
     context = kwargs.get('context')
     port_dict = kwargs.get('port')
     if l2gwservice:
