@@ -13,6 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from neutron.extensions import portbindings
+from neutron import manager
+
 from networking_l2gw._i18n import _LE
 from networking_l2gw.db.l2gateway import l2gateway_db
 from networking_l2gw.db.l2gateway.ovsdb import lib as db
@@ -23,9 +26,7 @@ from networking_l2gw.services.l2gateway.common import tunnel_calls
 from networking_l2gw.services.l2gateway import exceptions as l2gw_exc
 from networking_l2gw.services.l2gateway.service_drivers import agent_api
 
-from neutron_lib.api.definitions import portbindings
 from neutron_lib import constants
-from neutron_lib.plugins import directory
 from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging as messaging
@@ -43,17 +44,16 @@ class L2GatewayOVSDBCallbacks(object):
         self.plugin = plugin
         self.ovsdb = None
 
-    def update_ovsdb_changes(self, context, activity, ovsdb_data):
+    def update_ovsdb_changes(self, context, ovsdb_data):
         """RPC to update the changes from OVSDB in the database."""
         self.ovsdb = self.get_ovsdbdata_object(
             ovsdb_data.get(n_const.OVSDB_IDENTIFIER))
-        self.ovsdb.update_ovsdb_changes(context, activity, ovsdb_data)
+        self.ovsdb.update_ovsdb_changes(context, ovsdb_data)
 
     def notify_ovsdb_states(self, context, ovsdb_states):
         """RPC to notify the OVSDB servers connection state."""
         if ovsdb_states:
-            self.ovsdb = self.get_ovsdbdata_object(
-                list(ovsdb_states.keys())[0])
+            self.ovsdb = self.get_ovsdbdata_object(ovsdb_states.keys()[0])
         if self.ovsdb:
             LOG.debug("ovsdb_states = %s", ovsdb_states)
             self.ovsdb.notify_ovsdb_states(context, ovsdb_states)
@@ -71,30 +71,12 @@ class OVSDBData(object):
         self.agent_rpc = agent_api.L2gatewayAgentApi(
             topics.L2GATEWAY_AGENT, cfg.CONF.host)
         self.l2gw_mixin = l2gateway_db.L2GatewayMixin()
-        self.core_plugin = directory.get_plugin()
+        self.core_plugin = manager.NeutronManager.get_plugin()
         self.tunnel_call = tunnel_calls.Tunnel_Calls()
 
-    def _cleanup_all_ovsdb_tables(self, context, ovsdb_identifier):
-        db.delete_all_physical_locators_by_ovsdb_identifier(
-            context, ovsdb_identifier)
-        db.delete_all_physical_switches_by_ovsdb_identifier(
-            context, ovsdb_identifier)
-        db.delete_all_physical_ports_by_ovsdb_identifier(
-            context, ovsdb_identifier)
-        db.delete_all_logical_switches_by_ovsdb_identifier(
-            context, ovsdb_identifier)
-        db.delete_all_ucast_macs_locals_by_ovsdb_identifier(
-            context, ovsdb_identifier)
-        db.delete_all_ucast_macs_remotes_by_ovsdb_identifier(
-            context, ovsdb_identifier)
-        db.delete_all_vlan_bindings_by_ovsdb_identifier(
-            context, ovsdb_identifier)
-
-    def update_ovsdb_changes(self, context, activity, ovsdb_data):
+    def update_ovsdb_changes(self, context, ovsdb_data):
         """RPC to update the changes from OVSDB in the database."""
-        ovsdb_identifier = ovsdb_data.get('ovsdb_identifier')
-        if not activity:
-            self._cleanup_all_ovsdb_tables(context, ovsdb_identifier)
+
         for item, value in ovsdb_data.items():
             lookup = self.entry_table.get(item, None)
             if lookup:
@@ -325,11 +307,7 @@ class OVSDBData(object):
         call add_fdb_entries. otherwise, call tunnel_sync.
         """
         for mac in new_remote_macs:
-            try:
-                agent_l2_pop_enabled = self._get_agent_by_mac(context, mac)
-            except l2gw_exc.L2AgentNotFoundByHost as e:
-                LOG.debug(e.message)
-                continue
+            agent_l2_pop_enabled = self._get_agent_by_mac(context, mac)
             physical_switches = self._get_physical_switch_ips(context, mac)
             for physical_switch in physical_switches:
                 other_fdb_entries = self._get_fdb_entries(
