@@ -14,11 +14,11 @@
 #    under the License.
 
 import abc
-
+from neutron.common import rpc as n_rpc
 from neutron.db import agents_db
-from neutron_lib import rpc as n_rpc
+from neutron.extensions import portbindings
 
-from networking_l2gw._i18n import _
+from networking_l2gw._i18n import _LE
 from networking_l2gw.db.l2gateway import l2gateway_db as l2_gw_db
 from networking_l2gw.db.l2gateway.ovsdb import lib as db
 from networking_l2gw.services.l2gateway import agent_scheduler
@@ -30,15 +30,12 @@ from networking_l2gw.services.l2gateway import exceptions as l2gw_exc
 from networking_l2gw.services.l2gateway import service_drivers
 from networking_l2gw.services.l2gateway.service_drivers import agent_api
 
-from neutron.plugins.ml2 import managers
-
-from neutron_lib.api.definitions import portbindings
-from neutron_lib import constants as n_const
 from neutron_lib import exceptions
 from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging as messaging
 from oslo_utils import importutils
+import six
 
 LOG = logging.getLogger(__name__)
 
@@ -47,7 +44,8 @@ L2GW_CALLBACK = ("networking_l2gw.services.l2gateway.ovsdb."
                  "data.L2GatewayOVSDBCallbacks")
 
 
-class L2gwRpcDriver(service_drivers.L2gwDriver, metaclass=abc.ABCMeta):
+@six.add_metaclass(abc.ABCMeta)
+class L2gwRpcDriver(service_drivers.L2gwDriver):
     """L2gw RPC Service Driver class."""
 
     def __init__(self, service_plugin, validator=None):
@@ -56,7 +54,7 @@ class L2gwRpcDriver(service_drivers.L2gwDriver, metaclass=abc.ABCMeta):
             L2GW_CALLBACK, self)
         self.endpoints = (
             [self.ovsdb_callback, agents_db.AgentExtRpcCallback()])
-        self.conn = n_rpc.Connection()
+        self.conn = n_rpc.create_connection()
         self.conn.create_consumer(topics.L2GATEWAY_PLUGIN,
                                   self.endpoints,
                                   fanout=False)
@@ -66,8 +64,6 @@ class L2gwRpcDriver(service_drivers.L2gwDriver, metaclass=abc.ABCMeta):
         self.start_l2gateway_agent_scheduler()
         self.gateway_resource = constants.GATEWAY_RESOURCE_NAME
         self.l2gateway_db = l2_gw_db.L2GatewayMixin()
-        self.type_manager = managers.TypeManager()
-        self.port_dict_before_update = []
 
     @property
     def service_type(self):
@@ -143,8 +139,8 @@ class L2gwRpcDriver(service_drivers.L2gwDriver, metaclass=abc.ABCMeta):
                         except messaging.MessagingTimeout:
                             # If RPC is timed out, then the RabbitMQ
                             # will retry the operation.
-                            LOG.exception("Communication error with "
-                                          "the L2 gateway agent")
+                            LOG.exception(_LE("Communication error with "
+                                              "the L2 gateway agent"))
                         except Exception:
                             # The remote OVSDB server may be down.
                             # We need to retry this operation later.
@@ -171,8 +167,8 @@ class L2gwRpcDriver(service_drivers.L2gwDriver, metaclass=abc.ABCMeta):
                 except messaging.MessagingTimeout:
                     # If RPC is timed out, then the RabbitMQ
                     # will retry the operation.
-                    LOG.exception("Communication error with "
-                                  "the L2 gateway agent")
+                    LOG.exception(_LE("Communication error with "
+                                      "the L2 gateway agent"))
                 except Exception:
                     # The remote OVSDB server may be down.
                     # We need to retry this operation later.
@@ -234,57 +230,50 @@ class L2gwRpcDriver(service_drivers.L2gwDriver, metaclass=abc.ABCMeta):
                 if logical_switches:
                     for logical_switch in logical_switches:
                         logical_switch_uuid = logical_switch.get('uuid')
-                        macs = []
-                        if isinstance(port_dict.get("allowed_address_pairs"),
-                                      list):
-                            for address_pair in port_dict[
-                                    'allowed_address_pairs']:
-                                mac = address_pair['mac_address']
-                                macs.append(mac)
-                        macs.append(port_dict.get("mac_address"))
+                        mac = port_dict.get("mac_address")
                         if port_dict.get('ovsdb_identifier', None):
                             ovsdb_identifier = port_dict.get(
                                 'ovsdb_identifier')
                         else:
                             ovsdb_identifier = logical_switch.get(
                                 'ovsdb_identifier')
-
-                        if from_l2gw_plugin:
-                            ls = logical_switch.get('name')
-                            l2gateway_connections = (
-                                self.service_plugin.
-                                get_l2_gateway_connections(
-                                    context,
-                                    filters={'network_id': [ls]}))
-                            if len(l2gateway_connections) > 1:
-                                continue
-                        for mac in macs:
-                            record_dict = {'mac': mac,
-                                           'logical_switch_uuid':
-                                           logical_switch_uuid,
-                                           'ovsdb_identifier':
-                                           ovsdb_identifier}
-
-                            ucast_mac_remote = (
-                                db.get_ucast_mac_remote_by_mac_and_ls(
-                                    context, record_dict))
-                            del_count = 0
-                            if not ucast_mac_remote:
-                                LOG.debug("delete_port_mac: MAC %s does"
-                                          " not exist", mac)
-                                # It is possible that this MAC is present
-                                # in the pending_ucast_mac_remote table.
-                                # Delete this MAC as it was not inserted
-                                # into the OVSDB server earlier.
-                                del_count = db.delete_pending_ucast_mac_remote(
-                                    context, 'insert',
-                                    ovsdb_identifier,
-                                    logical_switch_uuid,
-                                    mac)
-                            if not del_count:
-                                mac_list = ls_dict.get(logical_switch_uuid, [])
-                                mac_list.append(mac)
-                                ls_dict[logical_switch_uuid] = mac_list
+                        record_dict = {'mac': mac,
+                                       'logical_switch_uuid':
+                                       logical_switch_uuid,
+                                       'ovsdb_identifier': ovsdb_identifier}
+                        rec_dict = {'logical_switch_id': logical_switch_uuid,
+                                    'ovsdb_identifier': ovsdb_identifier}
+                        if len(db.get_all_vlan_bindings_by_logical_switch(
+                               context, rec_dict)) > 1:
+                            if from_l2gw_plugin:
+                                ls = logical_switch.get('name')
+                                l2gateway_connections = (
+                                    self.service_plugin.
+                                    get_l2_gateway_connections(
+                                        context,
+                                        filters={'network_id': [ls]}))
+                                if len(l2gateway_connections) > 1:
+                                    continue
+                        ucast_mac_remote = (
+                            db.get_ucast_mac_remote_by_mac_and_ls(
+                                context, record_dict))
+                        del_count = 0
+                        if not ucast_mac_remote:
+                            LOG.debug("delete_port_mac: MAC %s does"
+                                      " not exist", mac)
+                            # It is possible that this MAC is present
+                            # in the pending_ucast_mac_remote table.
+                            # Delete this MAC as it was not inserted
+                            # into the OVSDB server earlier.
+                            del_count = db.delete_pending_ucast_mac_remote(
+                                context, 'insert',
+                                ovsdb_identifier,
+                                logical_switch_uuid,
+                                mac)
+                        if not del_count:
+                            mac_list = ls_dict.get(logical_switch_uuid, [])
+                            mac_list.append(mac)
+                            ls_dict[logical_switch_uuid] = mac_list
                 else:
                     LOG.debug("delete_port_mac:Logical Switch %s "
                               "does not exist ", port_dict.get('network_id'))
@@ -299,8 +288,8 @@ class L2gwRpcDriver(service_drivers.L2gwDriver, metaclass=abc.ABCMeta):
             except messaging.MessagingTimeout:
                 # If RPC is timed out, then the RabbitMQ
                 # will retry the operation.
-                LOG.exception("Communication error with "
-                              "the L2 gateway agent")
+                LOG.exception(_LE("Communication error with "
+                                  "the L2 gateway agent"))
             except Exception as ex:
                 # The remote OVSDB server may be down.
                 # We need to retry this operation later.
@@ -345,34 +334,6 @@ class L2gwRpcDriver(service_drivers.L2gwDriver, metaclass=abc.ABCMeta):
                         int_name=int_name, device_name=device_name,
                         fault_status=port_status)
 
-    def _validate_gateway_for_update(self, context, gw):
-        LOG.debug("L2gwRpcDriver._validate_gateway_for_update gw=%s",
-                  gw)
-        # Note(lajoskatona): If the update is updating other keys than
-        # devices, just return, as the tricky part is updating devices.
-        devices = gw['l2_gateway'].get('devices', [])
-
-        for device in devices:
-            interfaces = device.get('interfaces')
-            device_name = device.get("device_name")
-            for interface in interfaces:
-                interface_name = interface.get('name')
-                physical_switch = db.get_physical_switch_by_name(
-                    context, device.get('device_name'))
-                if not physical_switch:
-                    raise l2gw_exc.L2GatewayDeviceNotFound(
-                        device_id=device_name)
-                ovsdb_identifier = physical_switch.get('ovsdb_identifier')
-                pp_dict = {'interface_name': interface_name,
-                           'ovsdb_identifier': ovsdb_identifier,
-                           'physical_switch_id': physical_switch.get('uuid')}
-
-                ps_port = db.get_physical_port_by_name_and_ps(context, pp_dict)
-                if not ps_port:
-                    raise l2gw_exc.L2GatewayPhysicalPortNotFound(
-                        int_name=interface_name,
-                        device_name=device_name)
-
     def _validate_connection(self, context, gw_connection):
         seg_id = gw_connection.get('segmentation_id', None)
         l2_gw_id = gw_connection.get('l2_gateway_id')
@@ -414,12 +375,8 @@ class L2gwRpcDriver(service_drivers.L2gwDriver, metaclass=abc.ABCMeta):
         seg_id = gw_connection.get('segmentation_id', None)
         interfaces = self.service_plugin.get_l2gateway_interfaces_by_device_id(
             context, device['id'])
-        LOG.debug("L2gwRpcDriver._process_port_list: ints=%s",
-                  interfaces)
         for interface in interfaces:
             interface_name = interface.get('interface_name')
-            LOG.debug("L2gwRpcDriver._process_port_list: int_name=%s",
-                      interface_name)
             physical_switch = db.get_physical_switch_by_name(
                 context, device.get('device_name'))
             if not physical_switch:
@@ -447,8 +404,6 @@ class L2gwRpcDriver(service_drivers.L2gwDriver, metaclass=abc.ABCMeta):
                 raise Exception(msg)
             pp_dict['uuid'] = ps_port.get('uuid')
             pp_dict['name'] = ps_port.get('name')
-            LOG.debug("L2gwRpcDriver._process_port_list: pp_dict.name=%s",
-                      pp_dict['name'])
             port_dict = self._generate_port_list(
                 context, method, seg_id, interface, pp_dict,
                 logical_switch_uuid, gw_connection)
@@ -504,9 +459,6 @@ class L2gwRpcDriver(service_drivers.L2gwDriver, metaclass=abc.ABCMeta):
 
     def _get_ip_details(self, context, port):
         host = port[portbindings.HOST_ID]
-        if (not host and
-                (port['device_owner'] == n_const.DEVICE_OWNER_DVR_INTERFACE)):
-            return self._get_l3_dvr_agent_details(context, port)
         agent = self._get_agent_details(context, host)
         conf_dict = agent.get("configurations")
         dst_ip = conf_dict.get("tunneling_ip")
@@ -538,39 +490,6 @@ class L2gwRpcDriver(service_drivers.L2gwDriver, metaclass=abc.ABCMeta):
                 host=host)
         return l2_agent
 
-    def _get_l3_dvr_agent_details(self, context, port):
-        """Getting host IP for router port in DVR mode
-
-        in case of DVR, the router port will not have host information as
-        there is router in each Compute Node and in the Network Node.
-        Here we look for the L3 Agent in the Network Node, get its hostname and
-        resolve its hostname to IP address to be used as destination IP.
-        """
-        endpoints = self.type_manager.drivers.get('vxlan').obj.get_endpoints()
-        agents = self.service_plugin._core_plugin.get_agents(
-            context,
-            filters={
-                'agent_type': [n_const.AGENT_TYPE_L3],
-                'alive': ['true']
-            })
-        for agent in agents:
-            conf_dict = agent.get("configurations")
-            if conf_dict.get("agent_mode") == n_const.L3_AGENT_MODE_DVR_SNAT:
-                hostname = agent.get('host')
-                for endpoint in endpoints:
-                    if endpoint.get('host') == hostname:
-                        dst_ip = endpoint.get('ip_address')
-                        fixed_ip_list = port.get('fixed_ips')
-                        fixed_ip = fixed_ip_list[0].get('ip_address')
-                        LOG.debug(
-                            'Adding DVR dst_ip: %s, fixed_ip: %s',
-                            dst_ip,
-                            fixed_ip
-                        )
-                        return dst_ip, fixed_ip
-                raise l2gw_exc.DvrAgentHostnameNotFound(host=hostname)
-        raise l2gw_exc.L3DvrAgentNotFound()
-
     def _get_logical_switch_dict(self, context, logical_switch, gw_connection):
         if logical_switch:
             uuid = logical_switch.get('uuid')
@@ -638,115 +557,11 @@ class L2gwRpcDriver(service_drivers.L2gwDriver, metaclass=abc.ABCMeta):
         pass
 
     def update_l2_gateway(self, context, l2_gateway_id, l2_gateway):
-        """Check the port list for update"""
-        self.service_plugin._admin_check(context, 'UPDATE')
-        self._validate_gateway_for_update(context, l2_gateway)
-        self.port_dict_before_update = []
-        # get l2 gateway devices
-        l2gateway_devices = (
-            self.service_plugin.get_l2gateway_devices_by_gateway_id(
-                context, l2_gateway_id))
-        # get l2 gateway connections
-        gw_connections = self.service_plugin._get_l2_gateway_connections(
-            context)
-
-        for gw_connection in gw_connections:
-            for device in l2gateway_devices:
-                ovsdb_identifier, logical_switch, port_dict \
-                    = (self._process_port_list(context, device,
-                                               gw_connection, "UPDATE"))
-                self.port_dict_before_update.extend(port_dict)
+        """Update l2 gateway."""
+        pass
 
     def update_l2_gateway_postcommit(self, context, l2_gateway):
-        """Process the call from the CLI and trigger the RPC,
-
-        to update the connection of the gateway.
-        """
-        self.service_plugin._admin_check(context, 'UPDATE')
-
-        # get l2 gateway devices
-        l2gateway_devices = (
-            self.service_plugin.get_l2gateway_devices_by_gateway_id(
-                context, l2_gateway['id']))
-        # get l2 gateway connections
-        gw_connections = self.service_plugin._get_l2_gateway_connections(
-            context)
-
-        for gw_connection in gw_connections:
-            u_mac_dict = {}
-            mac_dict = {}
-            for device in l2gateway_devices:
-                locator_list = []
-                ovsdb_identifier, logical_switch, port_dict = (
-                    self._process_port_list(context, device,
-                                            gw_connection, "UPDATE"))
-                ls_dict = self._get_logical_switch_dict(
-                    context, logical_switch, gw_connection)
-                port_dict_before_update_con = \
-                    [port for port in self.port_dict_before_update
-                     if port['vlan_bindings'][0]['logical_switch_uuid'] ==
-                     logical_switch['uuid']]
-                port_dict_add = \
-                    [port for port in port_dict
-                     if port not in port_dict_before_update_con]
-                port_dict_delete = \
-                    [port for port in port_dict_before_update_con
-                     if port not in port_dict]
-                if port_dict_add:
-                    ports = self._get_port_details(
-                        context, gw_connection.get('network_id'))
-                    LOG.debug("L2gwRpcDriver.update_l2_gw: ports=%s", ports)
-                    for port in ports:
-                        mac_list = []
-                        if port['device_owner']:
-                            dst_ip, ip_address = self._get_ip_details(context,
-                                                                      port)
-                            mac_ip_pairs = []
-                            if isinstance(
-                                    port.get("allowed_address_pairs"), list):
-                                for address_pair in \
-                                        port['allowed_address_pairs']:
-                                    mac = address_pair['mac_address']
-                                    mac_ip_pairs.append(
-                                        (mac, address_pair['ip_address']))
-                            mac_ip_pairs.append((port.get('mac_address'),
-                                                 ip_address))
-
-                            for mac, ip in mac_ip_pairs:
-                                mac_remote = self._get_dict(
-                                    ovsdb_schema.UcastMacsRemote(
-                                        uuid=None,
-                                        mac=mac,
-                                        logical_switch_id=None,
-                                        physical_locator_id=None,
-                                        ip_address=ip))
-                                if logical_switch:
-                                    u_mac_dict['mac'] = mac
-                                    u_mac_dict['ovsdb_identifier'] = \
-                                        ovsdb_identifier
-                                    u_mac_dict['logical_switch_uuid'] = (
-                                        logical_switch.get('uuid'))
-                                    ucast_mac_remote = (
-                                        db.get_ucast_mac_remote_by_mac_and_ls(
-                                            context, u_mac_dict))
-                                    if not ucast_mac_remote:
-                                        mac_list.append(mac_remote)
-                                else:
-                                    mac_list.append(mac_remote)
-                            locator_list = self._get_locator_list(
-                                context, dst_ip, ovsdb_identifier, mac_list,
-                                locator_list)
-                    for locator in locator_list:
-                        mac_dict[locator.get('dst_ip')] = locator.pop('macs')
-                        locator.pop('ovsdb_identifier')
-                    self.agent_rpc.update_connection_to_gateway(
-                        context, ovsdb_identifier, ls_dict, locator_list,
-                        mac_dict, port_dict_add, 'CREATE')
-
-                if port_dict_delete:
-                    self.agent_rpc.update_connection_to_gateway(
-                        context, ovsdb_identifier, ls_dict, locator_list,
-                        mac_dict, port_dict_delete, 'DELETE')
+        pass
 
     def delete_l2_gateway(self, context, id):
         """delete the l2 gateway by id."""
@@ -770,6 +585,7 @@ class L2gwRpcDriver(service_drivers.L2gwDriver, metaclass=abc.ABCMeta):
         u_mac_dict = {}
         ls_dict = {}
         mac_dict = {}
+        is_mac = False
         self.service_plugin._admin_check(context, 'CREATE')
         gw_connection = l2_gateway_connection.get('l2_gateway_connection')
         # validate connection
@@ -787,28 +603,22 @@ class L2gwRpcDriver(service_drivers.L2gwDriver, metaclass=abc.ABCMeta):
                 context, logical_switch, gw_connection)
             ports = self._get_port_details(context,
                                            gw_connection.get('network_id'))
-            for port in ports:
-                mac_list = []
-                if port['device_owner']:
-                    dst_ip, ip_address = self._get_ip_details(context, port)
-                    mac_ip_pairs = []
-                    if isinstance(port.get("allowed_address_pairs"), list):
-                        for address_pair in port['allowed_address_pairs']:
-                            mac = address_pair['mac_address']
-                            mac_ip_pairs.append((mac,
-                                                 address_pair['ip_address']))
-                    mac_ip_pairs.append((port.get('mac_address'), ip_address))
-
-                    for mac, ip in mac_ip_pairs:
+            if not is_mac:
+                is_mac = True
+                for port in ports:
+                    mac_list = []
+                    if port['device_owner']:
+                        dst_ip, ip_address = self._get_ip_details(context,
+                                                                  port)
                         mac_remote = self._get_dict(
                             ovsdb_schema.UcastMacsRemote(
                                 uuid=None,
-                                mac=mac,
+                                mac=port.get('mac_address'),
                                 logical_switch_id=None,
                                 physical_locator_id=None,
-                                ip_address=ip))
+                                ip_address=ip_address))
                         if logical_switch:
-                            u_mac_dict['mac'] = mac
+                            u_mac_dict['mac'] = port.get('mac_address')
                             u_mac_dict['ovsdb_identifier'] = ovsdb_identifier
                             u_mac_dict['logical_switch_uuid'] = (
                                 logical_switch.get('uuid'))
@@ -819,9 +629,9 @@ class L2gwRpcDriver(service_drivers.L2gwDriver, metaclass=abc.ABCMeta):
                                 mac_list.append(mac_remote)
                         else:
                             mac_list.append(mac_remote)
-                    locator_list = self._get_locator_list(
-                        context, dst_ip, ovsdb_identifier, mac_list,
-                        locator_list)
+                        locator_list = self._get_locator_list(
+                            context, dst_ip, ovsdb_identifier, mac_list,
+                            locator_list)
             for locator in locator_list:
                 mac_dict[locator.get('dst_ip')] = locator.pop('macs')
                 locator.pop('ovsdb_identifier')
