@@ -14,21 +14,23 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import json
-import time
+from networking_l2gw._i18n import _LI
+from networking_l2gw.tests.api import base_l2gw
+from networking_l2gw.tests.scenario import ovsdb_connections
+from networking_l2gw.tests.tempest import config
 
 from neutron.tests.api import base
 from neutron.tests.tempest import exceptions
 from neutron.tests.tempest import manager
-from oslo_log import log
-from tempest.lib.common import rest_client
-from tempest.lib.common.utils import data_utils
-from tempest.lib.common.utils import test_utils
-from tempest.lib import exceptions as lib_exc
 
-from networking_l2gw.tests.api import base_l2gw
-from networking_l2gw.tests.scenario import ovsdb_connections
-from networking_l2gw.tests.tempest import config
+from oslo_log import log
+from tempest_lib.common import rest_client
+from tempest_lib.common.utils import data_utils
+from tempest_lib.common.utils import misc as misc_utils
+from tempest_lib import exceptions as lib_exc
+
+import json
+import time
 
 CONF = config.CONF
 LOG = log.getLogger(__name__)
@@ -119,8 +121,8 @@ class TestL2GatewayBasic(base.BaseAdminNetworkTest):
                 serverstatus = '/'.join((server_status, str(task_state)))
                 waitsec = (time.time() - start_time)
                 LOG.info(
-                    'State transition %(oldstatus)s => %(serverstatus)s'
-                    'after %(waitsec)d second wait' %
+                    _LI('State transition %(oldstatus)s => %(serverstatus)s'
+                        'after %(waitsec)d second wait') %
                     {'oldstatus': oldstatus, 'serverstatus': serverstatus,
                      'waitsec': waitsec}
                 )
@@ -142,7 +144,7 @@ class TestL2GatewayBasic(base.BaseAdminNetworkTest):
                             'timeout': timeout})
                 message += ' Current status: %s.' % server_status
                 message += ' Current task state: %s.' % task_state
-                caller = test_utils.find_test_caller()
+                caller = misc_utils.find_test_caller()
                 if caller:
                     message = '(%s) %s' % (caller, message)
                 raise exceptions.TimeoutException(message)
@@ -258,7 +260,7 @@ class TestL2GatewayBasic(base.BaseAdminNetworkTest):
             ip = port['ports'][i]['fixed_ips'][0]['ip_address']
             ip_mac_dict.update({mac: ip})
         try:
-            for key, value in ip_mac_dict.items():
+            for key, value in ip_mac_dict.iteritems():
                 row = objConnection.find_row(key, count_uuid, resp_dec)
                 self.assertIn(value, row)
         except Exception:
