@@ -14,6 +14,7 @@
 #    under the License.
 #
 
+import contextlib
 import copy
 import datetime
 
@@ -22,13 +23,12 @@ from oslo_config import cfg
 from oslo_service import loopingcall
 from oslo_utils import timeutils
 
-from neutron.agent.common import utils
 from neutron.common import topics
+from neutron import context as neutron_context
 from neutron.db import agents_db
 from neutron import manager
 from neutron.plugins.ml2 import rpc
 from neutron.tests import base
-from neutron_lib import context as neutron_context
 
 from networking_l2gw.services.l2gateway import agent_scheduler
 from networking_l2gw.services.l2gateway.common import constants as srv_const
@@ -93,44 +93,53 @@ class TestAgentScheduler(base.BaseTestCase):
         self.fake_i_agent_list.append(make_inactive_agent(
             '2000', srv_const.AGENT_TYPE_L2GATEWAY, 52, config))
 
-    @mock.patch.object(loopingcall, 'FixedIntervalLoopingCall')
-    @mock.patch.object(agent_scheduler.LOG, 'debug')
-    @mock.patch.object(agent_scheduler.LOG, 'error')
-    def test_initialize_thread(self, err, debug, loop_call):
-        self.agentsch.initialize_thread()
-        self.assertTrue(loop_call.called)
-        self.assertTrue(debug.called)
-        self.assertFalse(err.called)
+    def test_initialize_thread(self):
+        with contextlib.nested(
+            mock.patch.object(loopingcall, 'FixedIntervalLoopingCall'),
+            mock.patch.object(self.LOG, 'debug'),
+            mock.patch.object(self.LOG, 'error')
+        ) as (loop_call, debug, err):
+            self.agentsch.initialize_thread()
+            self.assertTrue(loop_call.called)
+            self.assertTrue(debug.called)
+            self.assertFalse(err.called)
 
-    @mock.patch.object(loopingcall, 'FixedIntervalLoopingCall',
-                       side_effect=RuntimeError)
-    def test_initialize_thread_loop_call_exception(self, loop_call):
-        with mock.patch.object(self.LOG, 'error') as log_err:
+    def test_initialize_thread_loop_call_exception(self):
+        with contextlib.nested(
+            mock.patch.object(loopingcall, 'FixedIntervalLoopingCall',
+                              side_effect=RuntimeError),
+            mock.patch.object(self.LOG, 'error')
+        ) as (loop_call, log_err):
             self.agentsch.initialize_thread()
             self.assertTrue(loop_call.called)
             self.assertTrue(log_err.called)
 
-    @mock.patch.object(manager, 'NeutronManager')
-    def test_select_agent_type_one_active(self, mgr):
+    def test_select_agent_type_one_active(self):
         config = {srv_const.L2GW_AGENT_TYPE: ''}
         self.populate_agent_lists(config)
 
-        with mock.patch.object(self.LOG, 'exception'):
+        with contextlib.nested(
+            mock.patch('__builtin__.sorted'),
+            mock.patch.object(manager, 'NeutronManager'),
+            mock.patch.object(self.LOG, 'exception')
+        ) as (mock_sorted, mgr, logger_call):
             self.agentsch._l2gwplugin = mock.Mock()
             self.agentsch._select_agent_type(self.context,
                                              self.fake_a_agent_list)
             self.agentsch.l2gwplugin.agent_rpc.set_monitor_agent_called_with(
                 self.context, self.fake_a_agent_list[0]['host'])
 
-    @mock.patch.object(manager, 'NeutronManager')
-    def test_select_agent_type_multiple_active(self, mgr):
+    def test_select_agent_type_multiple_active(self):
         config = {srv_const.L2GW_AGENT_TYPE: ''}
         self.populate_agent_lists(config)
         self.fake_a_agent_list.append(make_active_agent(
             '1001', srv_const.AGENT_TYPE_L2GATEWAY, config))
         self.agentsch._l2gwplugin = mock.Mock()
 
-        with mock.patch.object(self.LOG, 'exception'):
+        with contextlib.nested(
+            mock.patch.object(manager, 'NeutronManager'),
+            mock.patch.object(self.LOG, 'exception')
+        ) as (mgr, logger_call):
             self.agentsch._select_agent_type(self.context,
                                              self.fake_a_agent_list)
             self.agentsch.l2gwplugin.agent_rpc.set_monitor_agent_called_with(
@@ -144,23 +153,24 @@ class TestAgentScheduler(base.BaseTestCase):
         self.fake_a_agent_list.append(make_active_agent(
             '1001', srv_const.AGENT_TYPE_L2GATEWAY, config))
 
-        with mock.patch.object(self.agentsch,
-                               '_select_agent_type') as select_agent, \
-                mock.patch.object(
-                    self.plugin, 'get_agents',
-                    return_value=fake_all_agent_list) as get_agent_list, \
-                mock.patch.object(utils, 'is_agent_down',
-                                  return_value=False) as is_agt:
+        with contextlib.nested(
+            mock.patch.object(self.agentsch, '_select_agent_type'),
+            mock.patch.object(self.plugin, 'get_agents',
+                              return_value=fake_all_agent_list),
+            mock.patch.object(self.agentsch, 'is_agent_down',
+                              return_value=False)
+        ) as (select_agent, get_agent_list, is_agt):
             self.agentsch.monitor_agent_state()
             self.assertTrue(get_agent_list.called)
             self.assertTrue(select_agent.called)
             self.assertTrue(is_agt.called)
 
     def test_monitor_agent_state_exception_get_agents(self):
-        with mock.patch.object(
-                self.plugin, 'get_agents',
-                side_effect=Exception) as get_agent_list, \
-                mock.patch.object(self.LOG, 'exception') as exception_log:
+        with contextlib.nested(
+            mock.patch.object(self.plugin, 'get_agents',
+                              side_effect=Exception),
+            mock.patch.object(self.LOG, 'exception')
+        ) as (get_agent_list, exception_log):
             self.agentsch.monitor_agent_state()
             self.assertTrue(get_agent_list.called)
             self.assertTrue(exception_log.called)
